# Changelog

## Version 2:

* **2.2.28** Updating patterns to libphonenumber v8.13.11
* **2.2.27** Updating patterns to libphonenumber v8.13.10
* **2.2.26** Updating patterns to libphonenumber v8.13.9
* **2.2.25** Updating patterns to libphonenumber v8.13.8
* **2.2.24** Updating patterns to libphonenumber v8.13.7
* **2.2.23** Updating patterns to libphonenumber v8.13.6
* **2.2.22** Updating patterns to libphonenumber v8.13.5
* **2.2.21** Updating patterns to libphonenumber v8.13.4
* **2.2.20** Updating patterns to libphonenumber v8.13.3
* **2.2.19** Updating patterns to libphonenumber v8.13.2
* **2.2.18** Updating patterns to libphonenumber v8.13.1
* **2.2.17** Updating patterns to libphonenumber v8.13.0
* **2.2.16** Updating patterns to libphonenumber v8.12.57
* **2.2.15** Updating patterns to libphonenumber v8.12.56
* **2.2.14** Updating patterns to libphonenumber v8.12.55
* **2.2.13** Updating patterns to libphonenumber v8.12.54
* **2.2.12** Updating patterns to libphonenumber v8.12.53
* **2.2.11** Updating patterns to libphonenumber v8.12.52
* **2.2.10** Updating patterns to libphonenumber v8.12.51
* **2.2.9** Updating patterns to libphonenumber v8.12.50
* **2.2.8** Updating patterns to libphonenumber v8.12.49
* **2.2.7** Updating patterns to libphonenumber v8.12.48
* **2.2.6**
    * Updated setup.py
    * Updating patterns to libphonenumber v8.12.47
* **2.2.5** Updating patterns to libphonenumber v8.12.46
* **2.2.4** Updating patterns to libphonenumber v8.12.45
* **2.2.3** Updating patterns to libphonenumber v8.12.44
* **2.2.2** Updating patterns to libphonenumber v8.12.43
* **2.2.1** Updating patterns to libphonenumber v8.12.42
* **2.2.0**
    * Removed python 3.5
    * Updating patterns to libphonenumber v8.12.41
* **2.1.8** Updating patterns to libphonenumber v8.12.40
* **2.1.7** Updating patterns to libphonenumber v8.12.39
* **2.1.6** Updating patterns to libphonenumber v8.12.38
* **2.1.5** Updating patterns to libphonenumber v8.12.37
* **2.1.4** Updating patterns to libphonenumber v8.12.36
* **2.1.3** Updating patterns to libphonenumber v8.12.35
* **2.1.2** Updating patterns to libphonenumber v8.12.34
* **2.1.1** Updating patterns to libphonenumber v8.12.33
* **2.1.0**
    * Python 3.10 supported
    * Added github actions
    * Updating patterns to libphonenumber v8.12.32
* **2.0.14** Updating patterns to libphonenumber v8.12.31
* **2.0.13** Updating patterns to libphonenumber v8.12.30
* **2.0.12** Updating patterns to libphonenumber v8.12.29
* **2.0.11** Updating patterns to libphonenumber v8.12.28
* **2.0.10** Updating patterns to libphonenumber v8.12.27
* **2.0.9** Updating patterns to libphonenumber v8.12.26
* **2.0.8** Updating patterns to libphonenumber v8.12.25
* **2.0.7** Updating patterns to libphonenumber v8.12.24
* **2.0.6** Updating patterns to libphonenumber v8.12.23
* **2.0.5** Updating patterns to libphonenumber v8.12.22
* **2.0.4** Updating patterns to libphonenumber v8.12.21
* **2.0.3** Updating patterns to libphonenumber v8.12.20
* **2.0.2** Updating patterns to libphonenumber v8.12.19
* **2.0.1** Updating patterns to libphonenumber v8.12.18
* **2.0.0**
    * Added support for mobile phone numbers
    * Added separate calls to get mobile phone number and national phone number

## Version 1:

* **1.4.0** Added load_alt_patters function
* **1.3.14** Updating patterns to libphonenumber v8.12.17
* **1.3.13** Updating patterns to libphonenumber v8.12.16
* **1.3.12** Updating patterns to libphonenumber v8.12.15
* **1.3.11** Updating patterns to libphonenumber v8.12.14
* **1.3.10** Updating patterns to libphonenumber v8.12.13
* **1.3.9** Updating patterns to libphonenumber v8.12.12
* **1.3.8** Updating patterns to libphonenumber v8.12.11
* **1.3.7** Updating patterns to libphonenumber v8.12.10
* **1.3.6** Updating patterns to libphonenumber v8.12.9
* **1.3.5** Updating patterns to libphonenumber v8.12.8
* **1.3.4** Updating patterns to libphonenumber v8.12.7
* **1.3.3** Updating patterns to libphonenumber v8.12.6
* **1.3.2** Fix `MI` invalid pattern
* **1.3.1** Updating patterns to libphonenumber v8.12.5
* **1.3.0** Added the ability to build a module with old versions of libphonenumber
* **1.2.0** Added phone number generation by `country name` and `ISO 3166-3`
* **1.1.1** Updating patterns to libphonenumber v8.12.4
* **1.1.0** Added cli
* **1.0.0** The first stable release